# OwnTwin CLI

[![PyPI](https://img.shields.io/pypi/v/owntwin.svg)](https://pypi.python.org/pypi/owntwin/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/owntwin.svg)](https://pypistats.org/packages/owntwin)

OwnTwin CLI is a toolchain for [OwnTwin](https://github.com/owntwin/owntwin), a user-driven digital twin framework.

## Installation

```
pip install owntwin
```

_Note for Windows users:_ [Fiona](https://github.com/Toblerity/Fiona#installation) is required to be preinstalled.

## Usage

See the [documentation](https://beta.owntwin.com/docs/getting-started) for details.

```
owntwin init
owntwin add-terrain
owntwin add [module names...]
owntwin export
owntwin view
```
